import os
from PyPDF2 import PdfReader, PdfWriter

def remove_wide_pages(input_pdf):
    reader = PdfReader(input_pdf)
    writer = PdfWriter()

    # Get the width of the 12th page (or last page if fewer than 12 pages)
    baseline_width = reader.pages[min(11, len(reader.pages) - 1)].mediabox.width

    # Remove pages that are twice as wide or wider than the baseline
    for i, page in enumerate(reader.pages):
        if page.mediabox.width < baseline_width * 2:
            writer.add_page(page)
        else:
            print(f"Removing page {i+1} (width: {page.mediabox.width}) from {input_pdf}")

    # Overwrite the original PDF
    with open(input_pdf, "wb") as output_file:
        writer.write(output_file)

    print(f"Processed: {input_pdf}")

def process_pdfs_in_directory(directory):
    for root, dirs, files in os.walk(directory):
        for file in files:
            if file.lower().endswith('.pdf'):
                pdf_path = os.path.join(root, file)
                try:
                    remove_wide_pages(pdf_path)
                except Exception as e:
                    print(f"Error processing {pdf_path}: {str(e)}")

if __name__ == "__main__":
    current_directory = os.getcwd()
    process_pdfs_in_directory(current_directory)
    print("All PDFs have been processed.")